@@ -78,7 +78,7 @@ struct Cli {
     speed: f64,
 
     /// Disable animation loop
-    #[clap(long, default_value_t = agg::DEFAULT_NO_LOOP)]
+    #[clap(long)]
     no_loop: bool,
 
     /// Limit idle time to max number of seconds [default: 5]
@@ -115,7 +115,10 @@ fn main() -> Result<()> {
         _ => "debug",
     };
 
-    env_logger::Builder::from_env(env_logger::Env::default().default_filter_or(log_level)).init();
+    let env = env_logger::Env::default().default_filter_or(log_level);
+    env_logger::Builder::from_env(env)
+        .format_timestamp(None)
+        .init();
 
     let config = agg::Config {
         cols: cli.cols,
